@@ -101,6 +101,10 @@ bool get_wrap_data(char *wrapid, char *handler, char *cgi, t_wrap *wrap_data, ch
 
 		while (fgets(line, 256, fp) != NULL) {
 			rest = uncomment(line);
+			if (*rest == '\0') {
+				continue;
+			}
+
 			if (split_configline(rest, &item, &rest) == 0) {
 				strlower(item);
 				if (strcmp(item, "cgihandler") == 0) {
