@@ -262,9 +262,9 @@ int handle_error(t_session *session, int error_code) {
 
 /* Run a program
  */
-int run_program(t_session *session, char *program) {
+int run_program(t_session *session, char *program, int return_code) {
 	pid_t pid;
-	char ip[MAX_IP_STR_LEN], *pos, slash = '/';
+	char ip[MAX_IP_STR_LEN], value[10], *pos, slash = '/';
 	int result;
 
 	switch (pid = fork()) {
@@ -292,6 +292,9 @@ int run_program(t_session *session, char *program) {
 				if (inet_ntop(session->ip_address.family, &(session->ip_address.value), ip, MAX_IP_STR_LEN) != NULL) {
 					setenv("REMOTE_ADDR", ip, 1);
 				}
+				snprintf(value, 9, "%d", return_code);
+				setenv("HTTP_RETURN_CODE", value, 1);
+
 				headerfield_to_environment(session, NULL, "Range:", "HTTP_RANGE");
 				headerfield_to_environment(session, NULL, "Referer:", "HTTP_REFERER");
 				headerfield_to_environment(session, NULL, "User-Agent:", "HTTP_USER_AGENT");
@@ -1006,11 +1009,6 @@ int serve_client(t_session *session) {
 
 	switch (session->request_method) {
 		case GET:
-			if ((session->cgi_type == no_cgi) && (session->directory != NULL)) {
-				if (session->directory->run_on_download != NULL) {
-					run_program(session, session->directory->run_on_download);
-				}
-			}
 		case HEAD:
 			if (session->cgi_type != no_cgi) {
 				session->body = NULL;
@@ -1027,6 +1025,12 @@ int serve_client(t_session *session) {
 					result = show_index(session);
 				}
 			}
+
+			if ((session->request_method == GET) && (session->cgi_type == no_cgi) && (session->directory != NULL)) {
+				if (session->directory->run_on_download != NULL) {
+					run_program(session, session->directory->run_on_download, result);
+				}
+			}
 			break;
 		case POST:
 			if (session->cgi_type != no_cgi) {
@@ -1045,13 +1049,13 @@ int serve_client(t_session *session) {
 		case PUT:
 			result = handle_put_request(session);
 			if (((result == 201) || (result == 204)) && (session->host->run_on_alter != NULL)) {
-				run_program(session, session->host->run_on_alter);
+				run_program(session, session->host->run_on_alter, result);
 			}
 			break;
 		case DELETE:
 			result = handle_delete_request(session);
 			if ((result == 204) && (session->host->run_on_alter != NULL)) {
-				run_program(session, session->host->run_on_alter);
+				run_program(session, session->host->run_on_alter, result);
 			}
 			break;
 		default:
@@ -1816,20 +1820,17 @@ int run_server(t_settings *settings) {
 		if (close(STDIN_FILENO) == -1) {
 			fprintf(stderr, "Warning: error closing STDIN\n");
 		} else if (open("/dev/null", O_RDONLY) == -1) {
-			fprintf(stderr, "Error redirecting stdin\n");
-			return EXIT_FAILURE;
+			fprintf(stderr, "Warning: error redirecting stdin\n");
 		}
 		if (close(STDOUT_FILENO) == -1) {
 			fprintf(stderr, "Warning: error closing STDOUT\n");
 		} else if (open("/dev/null", O_WRONLY) == -1) {
-			fprintf(stderr, "Error redirecting stdout\n");
-			return EXIT_FAILURE;
+			fprintf(stderr, "Warning: error redirecting stdout\n");
 		}
 		if (close(STDERR_FILENO) == -1) {
 			fprintf(stderr, "Warning: error closing STDERR\n");
 		} else if (open("/dev/null", O_WRONLY) == -1) {
-			log_string(config->system_logfile, "Error redirecting stderr\n");
-			return EXIT_FAILURE;
+			log_string(config->system_logfile, "Warning: error redirecting stderr\n");
 		}
 	}
 
