@@ -433,20 +433,20 @@ t_filelist *read_filelist(char *directory) {
 				continue;
 			}
 
-			if ((file = (t_filelist*)malloc(sizeof(t_filelist))) != NULL) {
-				if ((file->name = strdup(dir_info->d_name)) == NULL) {
-					remove_filelist(filelist);
-					filelist = NULL;
-					break;
-				}
+			if ((file = (t_filelist*)malloc(sizeof(t_filelist))) == NULL) {
+				remove_filelist(filelist);
+				filelist = NULL;
+				break;
+			} else if ((file->name = strdup(dir_info->d_name)) == NULL) {
+				free(file);
+				remove_filelist(filelist);
+				filelist = NULL;
+				break;
+			} else {
 				file->size = status.st_size;
 				file->time = status.st_mtime;
 				file->is_dir = S_ISDIR(status.st_mode);
 				file->next = filelist;
-			} else {
-				remove_filelist(filelist);
-				filelist = NULL;
-				break;
 			}
 			filelist = file;
 		}
