@@ -62,7 +62,8 @@ int print_ssl_error(SSL *ssl, int code) {
 }
 #endif
 
-/* SSL multithread locking callback */
+/* SSL multithread locking callback
+ */
 static void locking_callback(int mode, int n, const char *file, int line) {
 	if ((n >= 0) && (n < lockcount)) {
 		if (mode & CRYPTO_LOCK) {
@@ -76,11 +77,14 @@ static void locking_callback(int mode, int n, const char *file, int line) {
 	}
 }
 
-/* SSL thread ID callback */
+/* SSL thread ID callback
+ */
 static unsigned long id_callback() {
 	return (unsigned long)pthread_self();
 }
 
+/* Password callback
+ */
 static int password_callback(char *buffer, int size, int rwflag, void *data) {
 	int len;
 
@@ -138,7 +142,7 @@ static int load_dh_params(SSL_CTX *context, char *file) {
 	return 0;
 }
 
-SSL_CTX *ssl_binding(char *keyfile, char *CA_cert, int verify_depth, char *dh_file, char *ciphers) {
+SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, char *dh_file, char *ciphers) {
 	SSL_METHOD *meth;
 	SSL_CTX    *context;
 	STACK_OF(X509_NAME) *ca_list;
@@ -155,7 +159,7 @@ SSL_CTX *ssl_binding(char *keyfile, char *CA_cert, int verify_depth, char *dh_fi
 	SSL_CTX_set_options(context, SSL_OP_NO_SSLv2);
 
 	if (SSL_CTX_use_certificate_chain_file(context, keyfile) != 1) {
-		fprintf(stderr, "Error while reading certificate from %s\n", keyfile);
+		fprintf(stderr, "Error while reading certificate (chain) from %s\n", keyfile);
 		return NULL;
 	}
 
@@ -171,15 +175,15 @@ SSL_CTX *ssl_binding(char *keyfile, char *CA_cert, int verify_depth, char *dh_fi
 		return NULL;
 	}
 
-	if (CA_cert != NULL) {
+	if (ca_cert != NULL) {
 		SSL_CTX_set_verify_depth(context, verify_depth);
 		SSL_CTX_set_verify(context, SSL_VERIFY_PEER | SSL_VERIFY_FAIL_IF_NO_PEER_CERT, 0);
-		if (SSL_CTX_load_verify_locations(context, CA_cert, NULL) != 1) {
+		if (SSL_CTX_load_verify_locations(context, ca_cert, NULL) != 1) {
 			fprintf(stderr, "Error while setting CA verify locations\n");
 			return NULL;
 		}
 
-		if ((ca_list = SSL_load_client_CA_file(CA_cert)) == NULL) {
+		if ((ca_list = SSL_load_client_CA_file(ca_cert)) == NULL) {
 			fprintf(stderr, "Error while loading CA certificate file\n");
 			return NULL;
 		}
@@ -197,7 +201,7 @@ SSL_CTX *ssl_binding(char *keyfile, char *CA_cert, int verify_depth, char *dh_fi
 			fprintf(stderr, "Error while setting cipher list\n");
 			return NULL;
 		}
-	}	
+	}
 
 	return context;
 }
@@ -282,7 +286,7 @@ void ssl_free(SSL_CTX *context) {
 	SSL_CTX_free(context);
 }
 
-int get_client_certificate(SSL *ssl_data, int size, char *subject, char *issuer) {
+int get_client_certificate(SSL *ssl_data, char *subject, char *issuer, int size) {
 	X509 *cert;
 
 	subject[size - 1] = '\0';
