@@ -1,6 +1,7 @@
 #ifndef _LIBSTR_H
 #define _LIBSTR_H
 
+#include <sys/types.h>
 #include <stdbool.h>
 
 int  str2int(const char *str);
@@ -20,6 +21,8 @@ const char *http_error(int code);
 bool decode_base64(char *base64);
 int  str_replace(char *src, char *from, char *to, char **dst);
 bool min_strlen(char *str, int n);
-int header_to_variable(char *header, char *variable, int size);
+int  header_to_variable(char *header, char *variable, int size);
+int  filesize2str(char *buffer, int len, off_t fsize);
+int  add_str(char **buffer, int *size, int extra_size, int *len, char *str);
 
 #endif
