@@ -7,7 +7,7 @@
 
 void init_log_module(void);
 void log_pid(t_config *config, pid_t pid);
-void log_string(char *logfile, char *mesg);
+void log_string(char *logfile, char *mesg, ...);
 void log_system(t_session *session, char *mesg);
 void log_file_error(t_session *session, char *file, char *mesg);
 void log_error(t_session *session, char *mesg);
@@ -17,5 +17,8 @@ void log_unban(char *logfile, t_ip_addr *ip_address, unsigned long connect_attem
 void log_cgi_error(t_session *session, char *mesg);
 void close_logfiles(t_host *host, bool force_close);
 void close_logfiles_for_cgi_run(t_host *host);
+#ifdef DEBUG
+void log_debug(t_session *session, char *mesg, ...);
+#endif
 
 #endif
