@@ -91,7 +91,7 @@ typedef struct type_session {
 	int             output_size;
 
 #ifdef DEBUG
-	char            *status;
+	int             thread_id;
 #endif
 } t_session;
 
@@ -111,8 +111,4 @@ bool client_is_rejected_bot(t_session *session);
 int  prevent_csrf(t_session *session);
 void close_socket(t_session *session);
 
-#ifdef DEBUG
-void set_client_status(t_session *session, char *status);
-#endif
-
 #endif
