@@ -71,7 +71,7 @@ extern char *hs_contyp;
 /* Read a file from disk and send it to the client.
  */
 int send_file(t_session *session) {
-	char *referer, *buffer = NULL, value[VALUE_SIZE + 1], *dot, *date, *range, *range_begin, *range_end;
+	char *referer, *buffer = NULL, value[VALUE_SIZE + 1], *dot, *date, *range, *range_begin, *range_end, *new_fod;
 	long bytes_read, total_bytes, size, speed;
 	off_t file_size, send_begin, send_end, send_size;
 	int  retval, handle;
@@ -120,8 +120,10 @@ int send_file(t_session *session) {
 			}
 
 			if (invalid_referer) {
-				free(session->file_on_disk);
-				if ((session->file_on_disk = (char*)malloc(strlen(session->host->imgref_replacement) + 4)) != NULL) { /* + 3 for ".gz" (gzip encoding) */
+				if ((new_fod = (char*)malloc(strlen(session->host->imgref_replacement) + 4)) != NULL) { /* + 3 for ".gz" (gzip encoding) */
+					free(session->file_on_disk);
+					session->file_on_disk = new_fod;
+
 					strcpy(session->file_on_disk, session->host->imgref_replacement);
 
 					if (get_target_extension(session) == -1) {
@@ -540,12 +542,11 @@ int execute_cgi(t_session *session) {
 						free(line);
 						return rr_SQL_INJECTION;
 					}
-					session->vars = line;
-					if (register_tempdata(&(session->tempdata), session->vars, tc_data) == -1) {
-						free(session->vars);
-						session->vars = NULL;
+					if (register_tempdata(&(session->tempdata), line, tc_data) == -1) {
+						free(line);
 						return -1;
 					}
+					session->vars = line;
 			}
 		}
 
@@ -560,13 +561,12 @@ int execute_cgi(t_session *session) {
 						free(line);
 						return rr_SQL_INJECTION;
 					}
-					session->body = line;
-					session->content_length = result;
-					if (register_tempdata(&(session->tempdata), session->body, tc_data) == -1) {
-						free(session->body);
-						session->body = NULL;
+					if (register_tempdata(&(session->tempdata), line, tc_data) == -1) {
+						free(line);
 						return -1;
 					}
+					session->body = line;
+					session->content_length = result;
 			}
 		}
 
@@ -581,12 +581,11 @@ int execute_cgi(t_session *session) {
 						free(line);
 						return rr_SQL_INJECTION;
 					}
-					session->cookie = line;
-					if (register_tempdata(&(session->tempdata), session->cookie, tc_data) == -1) {
-						free(session->cookie);
-						session->cookie = NULL;
+					if (register_tempdata(&(session->tempdata), line, tc_data) == -1) {
+						free(line);
 						return -1;
 					}
+					session->cookie = line;
 			}
 		}
 	}
@@ -632,7 +631,7 @@ int execute_cgi(t_session *session) {
 			return 503;
 		} else if ((cgi_info.from_cgi = connect_to_fcgi_server(connect_to)) == -1) {
 			connect_to->available = false;
-			log_string(session->config->system_logfile, "can't connect to FastCGI server");
+			log_string(session->config->system_logfile, "can't connect to FastCGI server %s", session->fcgi_server->fcgi_id);
 			return 503;
 		} else {
 			connect_to->available = true;
@@ -670,10 +669,6 @@ int execute_cgi(t_session *session) {
 	cgi_info.deadline = time(NULL) + session->host->time_for_cgi;
 
 	do {
-#ifdef DEBUG
-		set_client_status(session, "execute_cgi()::read_from_cgi()");
-#endif
-
 		if (time(NULL) > cgi_info.deadline) {
 			cgi_result = cgi_TIMEOUT;
 		} else if (session->cgi_type == fastcgi) {
@@ -681,9 +676,6 @@ int execute_cgi(t_session *session) {
 		} else {
 			cgi_result = read_from_cgi_process(session, &cgi_info);
 		}
-#ifdef DEBUG
-		set_client_status(session, NULL);
-#endif
 
 		switch (cgi_result) {
 			case cgi_ERROR:
@@ -910,25 +902,6 @@ int execute_cgi(t_session *session) {
 	return retval;
 }
 
-/* Converts a filesize to a string.
- */
-static int filesize2str(char *buffer, off_t fsize) {
-	int result = 0;
-
-	buffer[FILESIZE_BUFFER_SIZE - 1] = '\0';
-	if (fsize < KILOBYTE) {
-		result = snprintf(buffer, FILESIZE_BUFFER_SIZE - 1, "%llu byte", (long long)fsize);
-	} else if (fsize < MEGABYTE) {
-		result = snprintf(buffer, FILESIZE_BUFFER_SIZE - 1, "%0.1f kB", ((double)(fsize >> 6)) / 16);
-	} else if (fsize < GIGABYTE) {
-		result = snprintf(buffer, FILESIZE_BUFFER_SIZE - 1, "%0.1f MB", ((double)(fsize >> 16)) / 16);
-	} else {
-		result = snprintf(buffer, FILESIZE_BUFFER_SIZE - 1, "%0.1f GB", ((double)(fsize >> 26)) / 16);
-	}
-
-	return (result < 0) ? 0 : result;
-}
-
 /* Read the content of a directory and send it in a formatted list to the client.
  */
 int show_index(t_session *session) {
@@ -1007,26 +980,34 @@ int show_index(t_session *session) {
 	if (strcmp(session->uri, "/") == 0) {
 		alias = session->host->alias;
 		while (alias != NULL) {
-			if ((file = (t_filelist*)malloc(sizeof(t_filelist))) != NULL) {
-				if ((file->name = strdup(alias->key + 1)) == NULL) {
-					remove_filelist(filelist);
-					return 500;
-				}
-				file->size = 0;
-				file->time = time(NULL);
-				file->is_dir = true;
-				file->next = filelist;
-				filelist = file;
-			} else {
+			if ((file = (t_filelist*)malloc(sizeof(t_filelist))) == NULL) {
+				remove_filelist(filelist);
+				return 500;
+			} else if ((file->name = strdup(alias->key + 1)) == NULL) {
+				free(file);
 				remove_filelist(filelist);
 				return 500;
 			}
+			file->size = 0;
+			file->time = time(NULL);
+			file->is_dir = true;
+			file->next = filelist;
+			filelist = file;
+
 			alias = alias->next;
 		}
 	}
 
 	file = filelist = sort_filelist(filelist);
 
+#ifdef HAVE_XSLT
+	if (session->host->index_xslt != NULL) {
+		retval = show_index_via_xslt(session, filelist);
+		remove_filelist(filelist);
+		return retval;
+	}
+#endif
+
 	do {
 		if (session->keep_alive) {
 			if (send_buffer(session, hs_chunked, 28) == -1) {
@@ -1146,7 +1127,7 @@ int show_index(t_session *session) {
 				break;
 			}
 			if (file->is_dir == false) {
-				len = filesize2str(size, file->size);
+				len = filesize2str(size, FILESIZE_BUFFER_SIZE, file->size);
 				if (send_chunk(session, size, len) == -1) {
 					break;
 				}
@@ -1175,7 +1156,7 @@ int show_index(t_session *session) {
 		} else if (send_chunk(session, " files</td><td></td><td class=\"totalsize\">", 42) == -1) {
 			break;
 		}
-		len = filesize2str(size, total_fsize);
+		len = filesize2str(size, FILESIZE_BUFFER_SIZE, total_fsize);
 		if (send_chunk(session, size, len) == -1) {
 			break;
 		} else if (send_chunk(session, "</td><td></td></tr>\n</table>\n</body>\n</html>\n", 45) == -1) {
