@@ -15,6 +15,10 @@
 #define MAX_MATCH_LOOP  20
 
 t_url_toolkit *find_toolkit(char *toolkit_id, t_url_toolkit *url_toolkit) {
+	if (toolkit_id == NULL) {
+		return NULL;
+	}
+
 	while (url_toolkit != NULL) {
 		if (strcmp(url_toolkit->toolkit_id, toolkit_id) == 0) {
 			return url_toolkit;
@@ -28,6 +32,10 @@ t_url_toolkit *find_toolkit(char *toolkit_id, t_url_toolkit *url_toolkit) {
 static int replace(char *src, int ofs, int len, char *rep, char **dst) {
 	int len_rep;
 
+	if ((src == NULL) || (rep == NULL) || (dst == NULL)) {
+		return -1;
+	}
+
 	len_rep = strlen(rep);
 	if ((*dst = (char*)malloc(strlen(src) - len + len_rep + 1)) == NULL) {
 		return -1;
@@ -45,6 +53,10 @@ bool toolkit_setting(char *key, char *value, t_url_toolkit *toolkit) {
 	char *rest;
 	int loop;
 
+	if ((key == NULL) || (value == NULL) || (toolkit == NULL)) {
+		return false;
+	}
+
 	if (strcmp(key, "toolkitid") == 0) {
 		if ((toolkit->toolkit_id = strdup(value)) != NULL) {
 			return true;
@@ -249,17 +261,21 @@ static int do_rewrite(char *url, regex_t *regexp, char *rep, char **new_url, int
 	char *repl, *c, *sub, *tmp;
 	bool replaced;
 
+	if ((url == NULL) || (regexp == NULL) || (rep == NULL) || (new_url == NULL)) {
+		return -1;
+	}
+
 	*new_url = NULL;
 	while (loop-- > 0) {
 		if (regexec(regexp, url, 10, pmatch, 0) == REG_NOMATCH) {
 			break;
 		}
 		if ((ofs = pmatch[0].rm_so) == -1) {
-			return UT_ERROR;
+			return -1;
 		}
 
 		if ((repl = strdup(rep)) == NULL) {
-			return UT_ERROR;
+			return -1;
 		}
 
 		/* Replace '$x' in replacement string with substring.
@@ -274,7 +290,7 @@ static int do_rewrite(char *url, regex_t *regexp, char *rep, char **new_url, int
 						len = pmatch[i].rm_eo - pmatch[i].rm_so;
 						if ((sub = strdup(url + pmatch[i].rm_so)) == NULL) {
 							free(repl);
-							return UT_ERROR;
+							return -1;
 						}
 						sub[len] = '\0';
 					} else {
@@ -284,7 +300,7 @@ static int do_rewrite(char *url, regex_t *regexp, char *rep, char **new_url, int
 
 					if (replace(repl, n, 2, sub, &tmp) == -1) {
 						free(repl);
-						return UT_ERROR;
+						return -1;
 					}
 
 					if (replaced) {
@@ -305,7 +321,7 @@ static int do_rewrite(char *url, regex_t *regexp, char *rep, char **new_url, int
 		len_rep = strlen(repl);
 		if (replace(url, ofs, len, repl, new_url) == -1) {
 			free(repl);
-			return UT_ERROR;
+			return -1;
 		}
 		url = *new_url;
 
@@ -336,7 +352,7 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 			skip--;
 		} else switch (rule->action) {
 			case ta_match_rewrite:
-				if (do_rewrite(url, &(rule->pattern), rule->parameter, new_url, rule->match_loop) == UT_ERROR) {
+				if (do_rewrite(url, &(rule->pattern), rule->parameter, new_url, rule->match_loop) == -1) {
 					if (*new_url != NULL) {
 						free(*new_url);
 						*new_url = NULL;
@@ -360,7 +376,7 @@ int use_toolkit(char *url, char *toolkit_id, t_url_toolkit *url_toolkit, char **
 				}
 				break;
 			case ta_match_redirect:
-				if (do_rewrite(url, &(rule->pattern), rule->parameter, new_url, rule->match_loop) == UT_ERROR) {
+				if (do_rewrite(url, &(rule->pattern), rule->parameter, new_url, rule->match_loop) == -1) {
 					if (*new_url != NULL) {
 						free(*new_url);
 						*new_url = NULL;
