@@ -104,15 +104,6 @@ void dispose_result(t_line *config, bool free_content) {
 	}
 }
 
-#ifdef DEBUG
-void print_file(t_line *line) {
-	while (line != NULL) {
-		printf("%3d:%-25s [%s] = [%s]\n", line->linenr, line->file, line->key, line->value);
-		line = line->next;
-	}
-}
-#endif
-
 int read_directory(char *dir, t_line **config, t_line **aliases) {
 	t_filelist *filelist, *file;
 	char *path;
@@ -549,7 +540,7 @@ int check_main_config(char *config_dir) {
 void check_url_toolkit(char *config_dir, char **toolkit_id) {
 	t_line *config = NULL;
 	char input[MAX_INPUT_SIZE + 1], **id, *url, *new_url, *toolkit_fastcgi;
-	t_url_toolkit *url_toolkit, *toolkit = NULL;
+	t_url_toolkit *url_toolkit, *toolkit = NULL, *new_toolkit;
 	bool in_rule_section = false;
 	int result = 0;
 
@@ -577,10 +568,14 @@ void check_url_toolkit(char *config_dir, char **toolkit_id) {
 				return;
 			}
 		} else if ((strcmp(config->key, "urltoolkit") == 0) && (strcmp(config->value, "{") == 0)) {
+			if ((new_toolkit = (t_url_toolkit*)malloc(sizeof(t_url_toolkit))) == NULL) {
+				perror("malloc()");
+				return;
+			}
 			if (url_toolkit == NULL) {
-				url_toolkit = toolkit = (t_url_toolkit*)malloc(sizeof(t_url_toolkit));
+				url_toolkit = toolkit = new_toolkit;
 			} else {
-				toolkit->next = (t_url_toolkit*)malloc(sizeof(t_url_toolkit));
+				toolkit->next = new_toolkit;
 				toolkit = toolkit->next;
 			}
 			toolkit->toolkit_id = NULL;
