@@ -77,8 +77,7 @@ static void add_parameter(const char **params, char *key, char *value, int *i) {
 
 	if (key == NULL) {
 		return;
-	}
-	if (value == NULL) {
+	} else if (value == NULL) {
 		value = "";
 	}
 
@@ -145,81 +144,83 @@ static const char **get_transform_parameters(t_session *session) {
 	const char **params;
 	int i = 0;
 
-	if ((params = (const char**)malloc(sizeof(void*) * (MAX_PARAMETERS + 1))) != NULL) {
-		add_parameter(params, "REQUEST_METHOD", session->method, &i);
-		add_parameter(params, "REQUEST_URI", session->request_uri, &i);
-		add_parameter(params, "SERVER_PROTOCOL", session->http_version, &i);
-		if (inet_ntop(session->ip_address.family, &(session->ip_address.value), ip, MAX_IP_STR_LEN) != NULL) {
-			add_parameter(params, "REMOTE_ADDR", ip, &i);
-		}
-
-		value[19] = '\0';
-		snprintf(value, 9, "%d", session->binding->port);
-		add_parameter(params, "SERVER_PORT", value, &i);
-		add_parameter(params, "SERVER_NAME", *(session->host->hostname.item), &i);
-		add_parameter(params, "SERVER_SOFTWARE", "Hiawatha v"VERSION, &i);
-#ifdef HAVE_SSL
-		if (session->binding->use_ssl) {
-			add_parameter(params, "HTTP_SCHEME", "https", &i);
-		} else
-#endif
-			add_parameter(params, "HTTP_SCHEME", "http", &i);
-
-		if (session->http_auth == basic) {
-			add_parameter(params, "AUTH_TYPE", "Basic", &i);
-		} else if (session->http_auth == digest) {
-			add_parameter(params, "AUTH_TYPE", "Digest", &i);
-		}
-		add_parameter(params, "REMOTE_USER", session->remote_user, &i);
-
-		add_headerfield(session, params, "Accept:", "HTTP_ACCEPT", &i);
-		add_headerfield(session, params, "Accept-Charset:", "HTTP_ACCEPT_CHARSET", &i);
-		add_headerfield(session, params, "Accept-Language:", "HTTP_ACCEPT_LANGUAGE", &i);
-		add_headerfield(session, params, "Client-IP:", "HTTP_CLIENT_IP", &i);
-		add_headerfield(session, params, "From:", "HTTP_FROM", &i);
-		add_headerfield(session, params, "Host:", "HTTP_HOST", &i);
-		add_headerfield(session, params, "If-Modified-Since:", "HTTP_IF_MODIFIED_SINCE", &i);
-		add_headerfield(session, params, "If-Unmodified-Since:", "HTTP_IF_UNMODIFIED_SINCE", &i);
-		add_headerfield(session, params, "Range:", "HTTP_RANGE", &i);
-		add_headerfield(session, params, "Referer:", "HTTP_REFERER", &i);
-		add_headerfield(session, params, "User-Agent:", "HTTP_USER_AGENT", &i);
-		add_headerfield(session, params, "Via:", "HTTP_VIA", &i);
-
-		/* Convert X-* HTTP headers to HTTP_* variables
-		 */
-		headerfields = session->headerfields;
-		while (headerfields != NULL) {
-			if (strncmp(headerfields->data, "X-", 2) == 0) {
-				if (header_to_variable(headerfields->data, (char*)&variable, MAX_HEADER_LEN) != -1) {
-					add_parameter(params, variable, headerfields->data + headerfields->value_offset, &i);
-				}
-			}
-			headerfields = headerfields->next;
-		}
-
-		value[19] = '\0';
-		snprintf(value, 19, "%d", session->return_code);
-		add_parameter(params, "HTTP_RETURN_CODE", value, &i);
-		if (session->error_code != -1) {
-			snprintf(value, 9, "%d", session->error_code);
-			add_parameter(params, "HTTP_GENERATED_ERROR", value, &i);
-		}
-
-		add_parameter(params, "QUERY_STRING", session->vars, &i);
-		if (session->body != NULL) {
-			value[19] = '\0';
-			snprintf(value, 19, "%ld", session->content_length);
-			add_parameter(params, "CONTENT_LENGTH", value, &i);
-			add_headerfield(session, params, "Content-Type:", "CONTENT_TYPE", &i);
-		}
-
-		add_parameter_line(params, session->vars, '&', "GET_", &i);
-		add_parameter_line(params, session->body, '&', "POST_", &i);
-		add_parameter_line(params, session->cookie, ';', "COOKIE_", &i);
-
-		params[i] = NULL;
+	if ((params = (const char**)malloc(sizeof(void*) * (MAX_PARAMETERS + 1))) == NULL) {
+		return NULL;
 	}
 
+	add_parameter(params, "REQUEST_METHOD", session->method, &i);
+	add_parameter(params, "REQUEST_URI", session->request_uri, &i);
+	add_parameter(params, "SERVER_PROTOCOL", session->http_version, &i);
+	if (inet_ntop(session->ip_address.family, &(session->ip_address.value), ip, MAX_IP_STR_LEN) != NULL) {
+		add_parameter(params, "REMOTE_ADDR", ip, &i);
+	}
+
+	value[19] = '\0';
+	snprintf(value, 9, "%d", session->binding->port);
+	add_parameter(params, "SERVER_PORT", value, &i);
+	add_parameter(params, "SERVER_NAME", *(session->host->hostname.item), &i);
+	add_parameter(params, "SERVER_SOFTWARE", "Hiawatha v"VERSION, &i);
+#ifdef HAVE_SSL
+	if (session->binding->use_ssl) {
+		add_parameter(params, "HTTP_SCHEME", "https", &i);
+	} else
+#endif
+		add_parameter(params, "HTTP_SCHEME", "http", &i);
+
+	if (session->http_auth == basic) {
+		add_parameter(params, "AUTH_TYPE", "Basic", &i);
+	} else if (session->http_auth == digest) {
+		add_parameter(params, "AUTH_TYPE", "Digest", &i);
+	}
+	add_parameter(params, "REMOTE_USER", session->remote_user, &i);
+
+	add_headerfield(session, params, "Accept:", "HTTP_ACCEPT", &i);
+	add_headerfield(session, params, "Accept-Charset:", "HTTP_ACCEPT_CHARSET", &i);
+	add_headerfield(session, params, "Accept-Language:", "HTTP_ACCEPT_LANGUAGE", &i);
+	add_headerfield(session, params, "Client-IP:", "HTTP_CLIENT_IP", &i);
+	add_headerfield(session, params, "From:", "HTTP_FROM", &i);
+	add_headerfield(session, params, "Host:", "HTTP_HOST", &i);
+	add_headerfield(session, params, "If-Modified-Since:", "HTTP_IF_MODIFIED_SINCE", &i);
+	add_headerfield(session, params, "If-Unmodified-Since:", "HTTP_IF_UNMODIFIED_SINCE", &i);
+	add_headerfield(session, params, "Range:", "HTTP_RANGE", &i);
+	add_headerfield(session, params, "Referer:", "HTTP_REFERER", &i);
+	add_headerfield(session, params, "User-Agent:", "HTTP_USER_AGENT", &i);
+	add_headerfield(session, params, "Via:", "HTTP_VIA", &i);
+
+	/* Convert X-* HTTP headers to HTTP_* variables
+	 */
+	headerfields = session->headerfields;
+	while (headerfields != NULL) {
+		if (strncmp(headerfields->data, "X-", 2) == 0) {
+			if (header_to_variable(headerfields->data, (char*)&variable, MAX_HEADER_LEN) != -1) {
+				add_parameter(params, variable, headerfields->data + headerfields->value_offset, &i);
+			}
+		}
+		headerfields = headerfields->next;
+	}
+
+	value[19] = '\0';
+	snprintf(value, 19, "%d", session->return_code);
+	add_parameter(params, "HTTP_RETURN_CODE", value, &i);
+	if (session->error_code != -1) {
+		snprintf(value, 9, "%d", session->error_code);
+		add_parameter(params, "HTTP_GENERATED_ERROR", value, &i);
+	}
+
+	add_parameter(params, "QUERY_STRING", session->vars, &i);
+	if (session->body != NULL) {
+		value[19] = '\0';
+		snprintf(value, 19, "%ld", session->content_length);
+		add_parameter(params, "CONTENT_LENGTH", value, &i);
+		add_headerfield(session, params, "Content-Type:", "CONTENT_TYPE", &i);
+	}
+
+	add_parameter_line(params, session->vars, '&', "GET_", &i);
+	add_parameter_line(params, session->body, '&', "POST_", &i);
+	add_parameter_line(params, session->cookie, ';', "COOKIE_", &i);
+
+	params[i] = NULL;
+
 	return params;
 }
 
